##  Related Information
  * [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD "Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.")
  * [Using GraphQL with Python](https://help.sap.com/docs/leanix/ea/using-graphql-with-python?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to run GraphQL queries and mutations using Python.")
